==> fr.ac6.library.st_3.1.0.202202231116.jar: base-rootfs_1.0.0-r0/internal/genrootfs.sh <==
#! /bin/sh
#
# Generated script from System Workbench for Linux to create
# a Linux root filesystem skeleton 
#
# Warning : Please edit the file between the USER CODE braquets

## BEGIN USER CODE ##
## END USER CODE ##

## BEGIN RESERVED ##

here=$(pwd)
where=$(dirname $here)
sources=$here/sources/skeleton
output=$here/output/rootfs
resources=$here/resources

mkdir -p $output
cp -r --preserve=links $sources/* $output

## END RESERVED ##

## BEGIN USER CODE ##
## END USER CODE ##

## BEGIN RESERVED CODE 1 ##
chmod 777 $output/etc/network/if-pre-up.d/wait_iface; chown 0:0 $output/etc/network/if-pre-up.d/wait_iface
chmod 0755 $output/etc/network; chown 0:0 $output/etc/network
chmod 777 $output/var/cache; chown 0:0 $output/var/cache
chmod 777 $output/var; chown 0:0 $output/var
chmod 777 $output/lib; chown 0:0 $output/lib
chmod 0600 $output/etc/shadow; chown 0:0 $output/etc/shadow
chmod 0644 $output/etc/services; chown 0:0 $output/etc/services
chmod 755 $output/etc/network/if-post-down.d; chown 0:0 $output/etc/network/if-post-down.d
chmod 755 $output/etc/network/if-pre-up.d; chown 0:0 $output/etc/network/if-pre-up.d
chmod 777 $output/var/lib/misc; chown 0:0 $output/var/lib/misc
chmod 0644 $output/etc/profile; chown 0:0 $output/etc/profile
chmod 755 $output/etc/network/if-up.d; chown 0:0 $output/etc/network/if-up.d
chmod 0755 $output/etc; chown 0:0 $output/etc
chmod 0644 $output/etc/group; chown 0:0 $output/etc/group
chmod 777 $output/var/lib; chown 0:0 $output/var/lib
chmod 1777 $output/tmp; chown 0:0 $output/tmp
chmod 777 $output/usr/lib; chown 0:0 $output/usr/lib
chmod 644 $output/etc/passwd; chown 0:0 $output/etc/passwd
chmod 777 $output/usr/bin; chown 0:0 $output/usr/bin
chmod 777 $output/dev/pts; chown 0:0 $output/dev/pts
chmod 0644 $output/etc/protocols; chown 0:0 $output/etc/protocols
chmod 777 $output/sys; chown 0:0 $output/sys
chmod 777 $output/run; chown 0:0 $output/run
chmod 777 $output/opt; chown 0:0 $output/opt
chmod 0755 $output/etc/profile.d; chown 0:0 $output/etc/profile.d
chmod 777 $output/media; chown 0:0 $output/media
chmod 0755 $output/etc/init.d; chown 0:0 $output/etc/init.d
chmod 0644 $output/etc/fstab; chown 0:0 $output/etc/fstab
chmod 0644 $output/etc/hosts; chown 0:0 $output/etc/hosts
chmod 777 $output/var/lock; chown 0:0 $output/var/lock
chmod 777 $output/var/log; chown 0:0 $output/var/log
chmod 700 $output/root; chown 0:0 $output/root
chmod 755 $output/etc/network/if-down.d; chown 0:0 $output/etc/network/if-down.d
chmod 777 $output/usr/sbin; chown 0:0 $output/usr/sbin
chmod 777 $output/dev/shm; chown 0:0 $output/dev/shm
chmod 777 $output/etc/profile.d/umask.sh; chown 0:0 $output/etc/profile.d/umask.sh
chmod 777 $output/proc/mounts; chown 0:0 $output/proc/mounts
chmod 777 $output/var/spool; chown 0:0 $output/var/spool
chmod 777 $output/usr; chown 0:0 $output/usr
chmod 777 $output/var/run; chown 0:0 $output/var/run
chmod 777 $output/var/tmp; chown 0:0 $output/var/tmp
chmod 777 $output/mnt; chown 0:0 $output/mnt
chmod 755 $output/dev; chown 0:0 $output/dev
chmod 777 $output/proc; chown 0:0 $output/proc
chmod 0600 $output/etc/shadow-; chown 0:0 $output/etc/shadow-
chmod 0644 $output/etc/passwd-; chown 0:0 $output/etc/passwd-
chmod 0600 $output/etc/random-seed; chown 0:0 $output/etc/random-seed
chmod 0644 $output/etc/issue; chown 0:0 $output/etc/issue
chmod 0755 $output/etc/init.d/S20urandom; chown 0:0 $output/etc/init.d/S20urandom
chmod 0755 $output/etc/init.d/S01logging; chown 0:0 $output/etc/init.d/S01logging
chmod 0755 $output/etc/init.d/S40network; chown 0:0 $output/etc/init.d/S40network
chmod 0777 $output/etc/resolv.conf; chown 0:0 $output/etc/resolv.conf
chmod 0644 $output/etc/nsswitch.conf; chown 0:0 $output/etc/nsswitch.conf
chmod 0644 $output/etc/hostname; chown 0:0 $output/etc/hostname
chmod 0755 $output/etc/init.d/functions; chown 0:0 $output/etc/init.d/functions

## END RESERVED CODE 1 ##

## BEGIN USER CODE ##
## END USER CODE ##

==> fr.ac6.library.st_3.1.0.202303061651.jar: base-rootfs_1.0.0-r0/internal/genrootfs.sh <==
#! /bin/sh
#
# Generated script from System Workbench for Linux to create
# a Linux root filesystem skeleton 
#
# Warning : Please edit the file between the USER CODE braquets

## BEGIN USER CODE ##
## END USER CODE ##

## BEGIN RESERVED ##

here=$(pwd)
where=$(dirname $here)
sources=$here/sources/skeleton
output=$here/output/rootfs
resources=$here/resources

mkdir -p $output
cp -r --preserve=links $sources/* $output

## END RESERVED ##

## BEGIN USER CODE ##
## END USER CODE ##

## BEGIN RESERVED CODE 1 ##
chmod 777 $output/etc/network/if-pre-up.d/wait_iface; chown 0:0 $output/etc/network/if-pre-up.d/wait_iface
chmod 0755 $output/etc/network; chown 0:0 $output/etc/network
chmod 777 $output/var/cache; chown 0:0 $output/var/cache
chmod 777 $output/var; chown 0:0 $output/var
chmod 777 $output/lib; chown 0:0 $output/lib
chmod 0600 $output/etc/shadow; chown 0:0 $output/etc/shadow
chmod 0644 $output/etc/services; chown 0:0 $output/etc/services
chmod 755 $output/etc/network/if-post-down.d; chown 0:0 $output/etc/network/if-post-down.d
chmod 755 $output/etc/network/if-pre-up.d; chown 0:0 $output/etc/network/if-pre-up.d
chmod 777 $output/var/lib/misc; chown 0:0 $output/var/lib/misc
chmod 0644 $output/etc/profile; chown 0:0 $output/etc/profile
chmod 755 $output/etc/network/if-up.d; chown 0:0 $output/etc/network/if-up.d
chmod 0755 $output/etc; chown 0:0 $output/etc
chmod 0644 $output/etc/group; chown 0:0 $output/etc/group
chmod 777 $output/var/lib; chown 0:0 $output/var/lib
chmod 1777 $output/tmp; chown 0:0 $output/tmp
chmod 777 $output/usr/lib; chown 0:0 $output/usr/lib
chmod 644 $output/etc/passwd; chown 0:0 $output/etc/passwd
chmod 777 $output/usr/bin; chown 0:0 $output/usr/bin
chmod 777 $output/dev/pts; chown 0:0 $output/dev/pts
chmod 0644 $output/etc/protocols; chown 0:0 $output/etc/protocols
chmod 777 $output/sys; chown 0:0 $output/sys
chmod 777 $output/run; chown 0:0 $output/run
chmod 777 $output/opt; chown 0:0 $output/opt
chmod 0755 $output/etc/profile.d; chown 0:0 $output/etc/profile.d
chmod 777 $output/media; chown 0:0 $output/media
chmod 0755 $output/etc/init.d; chown 0:0 $output/etc/init.d
chmod 0644 $output/etc/fstab; chown 0:0 $output/etc/fstab
chmod 0644 $output/etc/hosts; chown 0:0 $output/etc/hosts
chmod 777 $output/var/lock; chown 0:0 $output/var/lock
chmod 777 $output/var/log; chown 0:0 $output/var/log
chmod 700 $output/root; chown 0:0 $output/root
chmod 755 $output/etc/network/if-down.d; chown 0:0 $output/etc/network/if-down.d
chmod 777 $output/usr/sbin; chown 0:0 $output/usr/sbin
chmod 777 $output/dev/shm; chown 0:0 $output/dev/shm
chmod 777 $output/etc/profile.d/umask.sh; chown 0:0 $output/etc/profile.d/umask.sh
chmod 777 $output/proc/mounts; chown 0:0 $output/proc/mounts
chmod 777 $output/var/spool; chown 0:0 $output/var/spool
chmod 777 $output/usr; chown 0:0 $output/usr
chmod 777 $output/var/run; chown 0:0 $output/var/run
chmod 777 $output/var/tmp; chown 0:0 $output/var/tmp
chmod 777 $output/mnt; chown 0:0 $output/mnt
chmod 755 $output/dev; chown 0:0 $output/dev
chmod 777 $output/proc; chown 0:0 $output/proc
chmod 0600 $output/etc/shadow-; chown 0:0 $output/etc/shadow-
chmod 0644 $output/etc/passwd-; chown 0:0 $output/etc/passwd-
chmod 0600 $output/etc/random-seed; chown 0:0 $output/etc/random-seed
chmod 0644 $output/etc/issue; chown 0:0 $output/etc/issue
chmod 0777 $output/etc/resolv.conf; chown 0:0 $output/etc/resolv.conf
chmod 0644 $output/etc/nsswitch.conf; chown 0:0 $output/etc/nsswitch.conf
chmod 0644 $output/etc/hostname; chown 0:0 $output/etc/hostname
chmod 0755 $output/etc/init.d/functions; chown 0:0 $output/etc/init.d/functions
chmod 0755 $output/etc/ld.so.conf.d; chown 0:0 $output/etc/init.d/functions
chmod 0644 $output/etc/ld.so.conf; chown 0:0 $output/etc/init.d/functions
chmod 0755 $output/home; chown 0:0 $output/home
chmod 0755 $output/home/root; chown 0:0 $output/home/root

## END RESERVED CODE 1 ##

## BEGIN USER CODE ##
## END USER CODE ##
